@@ -143,21 +143,23 @@
   ;; mime-library-product
   (and rail-user-agent-replace-mime-library-product
        (boundp 'mime-library-product)
-       (setq codename (mime-product-code-name mime-library-product))
-       (aset mime-library-product 2
-	     (or (rail-assoc codename
-			     (append rail-additional-flim-codename-alist rail-flim-codename-alist)
-			     rail-convert-direction)
-		 codename)))
+       (let ((codename (mime-product-code-name mime-library-product)))
+	 (aset mime-library-product 2
+	       (or (rail-assoc
+		    codename
+		    (append rail-additional-flim-codename-alist rail-flim-codename-alist)
+		    rail-convert-direction)
+		   codename))))
   ;; mime-user-interface-product
   (and rail-user-agent-replace-mime-user-interface-product
        (boundp 'mime-user-interface-product)
-       (setq codename (mime-product-code-name mime-user-interface-product))
-       (aset mime-user-interface-product 2
-	     (or (rail-assoc codename
-			     (append rail-additional-semi-codename-alist rail-semi-codename-alist)
-			     rail-convert-direction)
-		 codename))))
+       (let ((codename (mime-product-code-name mime-user-interface-product)))
+	 (aset mime-user-interface-product 2
+	       (or (rail-assoc
+		    codename
+		    (append rail-additional-semi-codename-alist rail-semi-codename-alist)
+		    rail-convert-direction)
+		   codename)))))
 
 ;; add mime-edit-translate-buffer-hook
 (defun rail-user-agent-add-hook ()
@@ -175,6 +177,37 @@
   (rail-user-agent-add-hook)
   (rail-user-agent-replace-string))
 
+;; for mime-view mode
+(defun rail-mime-save-situation-examples ()
+  (save-excursion
+    (or (and rail-user-agent-convert-mime-example
+	     (set-buffer (get-buffer-create rail-temporary-buffer-name))
+	     (progn
+	       (erase-buffer)
+	       (insert mime-view-version)
+	       (goto-char (point-min))
+	       (and (looking-at rail-mime-view-version-format)
+		    (eq 'semi (cdr (assoc (buffer-substring
+					   (match-beginning 1)
+					   (match-end 1))
+					  rail-product-name-alist)))
+		    (rail-replace-codename-primitive
+		     rail-mime-view-version-format
+		     rail-additional-semi-codename-alist rail-semi-codename-alist))
+	       (let ((mime-view-version
+		      (buffer-substring (point-min) (point-max))))
+		 (rail-mime-save-situation-examples-original))
+	       t))
+	(rail-mime-save-situation-examples-original))))
+
+(and (fboundp 'eval-after-load)
+     (eval-after-load "mime-view"
+       '(progn
+	  (if (not (fboundp 'rail-mime-save-situation-examples-original))
+	      (fset 'rail-mime-save-situation-examples-original
+		    (symbol-function 'mime-save-situation-examples)))
+	  (fset 'mime-save-situation-examples 'rail-mime-save-situation-examples))))
+
 (provide 'rail-user-agent)
 
 ;;; rail-user-agent.el ends here
